@@ -1,7 +1,7 @@
 package Bencher::Scenario::DigestMD5;
 
-our $DATE = '2016-11-21'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,7 @@ our $scenario = {
     participants => [
         {
             name   => 'md5sum',
-            modules => ['String::ShellQuote'],
+            helper_modules => ['String::ShellQuote'],
             code_template => 'my $cmd = "md5sum ".String::ShellQuote::shell_quote(<filename>); my $res = `$cmd`; $res =~ s/\s.+//s; $res',
         },
         {
@@ -82,7 +82,7 @@ Bencher::Scenario::DigestMD5 - Benchmark Digest::MD5 against md5sum utility
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DigestMD5 (from Perl distribution Bencher-Scenario-DigestMD5), released on 2016-11-21.
+This document describes version 0.003 of Bencher::Scenario::DigestMD5 (from Perl distribution Bencher-Scenario-DigestMD5), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -104,8 +104,6 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<String::ShellQuote> 1.04
-
 L<Digest::MD5> 2.54
 
 =head1 BENCHMARK PARTICIPANTS
@@ -140,29 +138,31 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m DigestMD5 >>):
 
  #table1#
- +-------------+-----------+-----------+------------+---------+---------+
- | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +-------------+-----------+-----------+------------+---------+---------+
- | md5sum      |      20   |        50 |       1    |   8e-05 |       6 |
- | Digest::MD5 |      21.3 |        47 |       1.06 | 1.2e-05 |       6 |
- +-------------+-----------+-----------+------------+---------+---------+
+ +-------------+-----------+-----------+------------+-----------+---------+
+ | participant | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-------------+-----------+-----------+------------+-----------+---------+
+ | Digest::MD5 |        14 |        70 |        1   |   0.00013 |       6 |
+ | md5sum      |        15 |        66 |        1.1 | 8.2e-05   |       6 |
+ +-------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DigestMD5 --module-startup >>):
 
  #table2#
- +---------------------+-----------+------------------------+------------+---------+---------+
- | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+-----------+------------------------+------------+---------+---------+
- | Digest::MD5         |      5.7  |                   3.2  |       1    |   4e-05 |       7 |
- | String::ShellQuote  |      5.16 |                   2.66 |       1.11 |   4e-06 |       6 |
- | perl -e1 (baseline) |      2.5  |                   0    |       2.3  | 1.6e-05 |       6 |
- +---------------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | Digest::MD5         | 1112                         | 4.55               | 18.3           |      8.95 |                   4.35 |        1   | 3.3e-06 |       8 |
+ | perl -e1 (baseline) | 1052                         | 4.3                | 16             |      4.6  |                   0    |        1.9 | 6.9e-06 |       6 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+
+
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 BENCHMARK NOTES
 
@@ -190,7 +190,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
